module.exports = defineTest({
	description: 'indentation is preserved in multi-line strings'
});
